aboutsummaryrefslogtreecommitdiffstats
path: root/source/stmdsp
diff options
context:
space:
mode:
Diffstat (limited to 'source/stmdsp')
-rw-r--r--source/stmdsp/stmdsp.cpp40
-rw-r--r--source/stmdsp/stmdsp.hpp21
2 files changed, 34 insertions, 27 deletions
diff --git a/source/stmdsp/stmdsp.cpp b/source/stmdsp/stmdsp.cpp
index 2252364..d7e977b 100644
--- a/source/stmdsp/stmdsp.cpp
+++ b/source/stmdsp/stmdsp.cpp
@@ -90,8 +90,7 @@ namespace stmdsp
m_serial->write(cmd.data(), cmd.size());
success = true;
} catch (...) {
- m_serial.release();
- log("Lost connection!");
+ handle_disconnect();
}
}
@@ -108,8 +107,7 @@ namespace stmdsp
m_serial->read(dest, dest_size);
success = true;
} catch (...) {
- m_serial.release();
- log("Lost connection!");
+ handle_disconnect();
}
}
@@ -158,12 +156,11 @@ namespace stmdsp
m_is_running = true;
}
- void device::continuous_start_measure() {
- if (try_command({'M'}))
- m_is_running = true;
+ void device::measurement_start() {
+ try_command({'M'});
}
- uint32_t device::continuous_start_get_measurement() {
+ uint32_t device::measurement_read() {
uint32_t count = 0;
try_read({'m'}, reinterpret_cast<uint8_t *>(&count), sizeof(uint32_t));
return count / 2;
@@ -193,8 +190,7 @@ namespace stmdsp
}
} catch (...) {
- m_serial.release();
- log("Lost connection!");
+ handle_disconnect();
}
}
@@ -225,8 +221,7 @@ namespace stmdsp
}
} catch (...) {
- m_serial.release();
- log("Lost connection!");
+ handle_disconnect();
}
}
@@ -251,8 +246,7 @@ namespace stmdsp
m_serial->write(request, 3);
m_serial->write((uint8_t *)buffer, size * sizeof(dacsample_t));
} catch (...) {
- m_serial.release();
- log("Lost connection!");
+ handle_disconnect();
}
} else {
try {
@@ -262,8 +256,7 @@ namespace stmdsp
else
m_serial->write((uint8_t *)buffer, size * sizeof(dacsample_t));
} catch (...) {
- m_serial.release();
- log("Lost connection!");
+ handle_disconnect();
}
}
@@ -295,8 +288,7 @@ namespace stmdsp
m_serial->write(request, 3);
m_serial->write(buffer, size);
} catch (...) {
- m_serial.release();
- log("Lost connection!");
+ handle_disconnect();
}
}
}
@@ -318,9 +310,19 @@ namespace stmdsp
bool running = ret.first == RunStatus::Running;
if (m_is_running != running)
m_is_running = running;
+ } else if (m_disconnect_error_flag) {
+ m_disconnect_error_flag = false;
+ return {RunStatus::Idle, Error::GUIDisconnect};
}
return ret;
}
-}
+
+ void device::handle_disconnect()
+ {
+ m_disconnect_error_flag = true;
+ m_serial.release();
+ log("Lost connection!");
+ }
+} // namespace stmdsp
diff --git a/source/stmdsp/stmdsp.hpp b/source/stmdsp/stmdsp.hpp
index e0fca90..efed8a3 100644
--- a/source/stmdsp/stmdsp.hpp
+++ b/source/stmdsp/stmdsp.hpp
@@ -63,12 +63,15 @@ namespace stmdsp
*/
enum class Error : char {
None = 0,
- BadParam, /* An invalid parameter was passed for a command. */
- BadParamSize, /* An invaild param. size was given for a command. */
- BadUserCodeLoad, /* Device failed to load the given algorithm. */
- BadUserCodeSize, /* The given algorithm is too large for the device. */
- NotIdle, /* An idle-only command was received while not Idle. */
- ConversionAborted /* A conversion was aborted due to a fault. */
+ BadParam, /* An invalid parameter was passed for a command. */
+ BadParamSize, /* An invaild param. size was given for a command. */
+ BadUserCodeLoad, /* Device failed to load the given algorithm. */
+ BadUserCodeSize, /* The given algorithm is too large for the device. */
+ NotIdle, /* An idle-only command was received while not Idle. */
+ ConversionAborted, /* A conversion was aborted due to a fault. */
+ NotRunning, /* A running-only command was received while not Running. */
+
+ GUIDisconnect = 100 /* The GUI lost connection with the device. */
};
/**
@@ -123,8 +126,8 @@ namespace stmdsp
void continuous_start();
void continuous_stop();
- void continuous_start_measure();
- uint32_t continuous_start_get_measurement();
+ void measurement_start();
+ uint32_t measurement_read();
std::vector<adcsample_t> continuous_read();
std::vector<adcsample_t> continuous_read_input();
@@ -149,11 +152,13 @@ namespace stmdsp
unsigned int m_sample_rate = 0;
bool m_is_siggening = false;
bool m_is_running = false;
+ bool m_disconnect_error_flag = false;
std::mutex m_lock;
bool try_command(std::basic_string<uint8_t> data);
bool try_read(std::basic_string<uint8_t> cmd, uint8_t *dest, unsigned int dest_size);
+ void handle_disconnect();
};
}